# NAME

casl - simple implementation of CASL assembler/COMET simulator in Python

# WHAT IS CASL?

*casl* is simple implementation of CASL assembler and COMET simulator written
in Python.  The CASL assembler and the COMET simulator are designed for users
to study principle operations of computers.  In particular, CASL and COMET are
used in a qualifying examination called as Japan Information-Technology
Engineers Examination so that these programs would be of value for people who
would like to acquire this qualification.

Since both the CASL assembler and the COMET simulator are written only in
Python, these should work on almost all operating system
including UNIX flavors, Windows, and macOS.

*casl* includes the following programs:

- *casl* - a simple implementation of CASL assembler in Python

- *comet* - a simple implementation of COMET simulator in Python

# AVAILABILITY

The latest version of *casl* is available at https://pypi.org/project/casl/ .

# COPYRIGHT

Copyright (C) 2021 Hiroyuki Ohsaki (ohsaki[atmark]lsnl.jp)

# INSTALLATION

``` sh
sudo pip3 install casl
```

# FEEDBACK

If you find any bugs, first check if a newer version exists.  If not, please
send bug report or fixing patch to me.  I appreciate your comments and/or
suggestions.

# AUTHOR

Hiroyuki Ohsaki <ohsaki[atmark]lsnl.jp>

